@@ -1,4 +1,4 @@
-version_info = (1, 0, 17)
+version_info = (1, 0, 18)
 
 __version__ = version = '.'.join(map(str, version_info))
 __project__ = PROJECT = __name__
@@ -7,7 +7,11 @@ __license__ = LICENSE = "GNU LGPL"
 
 
 # Preload ADREST tags
-from django.template import builtins
-from .templatetags import register
+try:
+    from django.template import builtins
+    from .templatetags import register
 
-builtins.append(register)
+    builtins.append(register)
+
+except ImportError:
+    pass
